/****************************************************************************
** Meta object code from reading C++ file 'transportmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kmailtransport-26.07.80/src/transportmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transportmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13MailTransport16TransportManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto MailTransport::TransportManager::qt_create_metaobjectdata<qt_meta_tag_ZN13MailTransport16TransportManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MailTransport::TransportManager",
        "D-Bus Interface",
        "org.kde.pim.TransportManager",
        "transportsChanged",
        "",
        "changesCommitted",
        "passwordsChanged",
        "transportRemoved",
        "id",
        "name",
        "transportRenamed",
        "oldName",
        "newName",
        "slotTransportsChanged",
        "isEmpty",
        "transportIds",
        "QList<int>",
        "transportNames",
        "defaultTransportName",
        "defaultTransportId",
        "setDefaultTransport",
        "removeTransport"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'transportsChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Signal 'changesCommitted'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void),
        // Signal 'passwordsChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transportRemoved'
        QtMocHelpers::SignalData<void(int, const QString &)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'transportRenamed'
        QtMocHelpers::SignalData<void(int, const QString &, const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'slotTransportsChanged'
        QtMocHelpers::SlotData<void()>(13, 4, QMC::AccessPrivate, QMetaType::Void),
        // Method 'isEmpty'
        QtMocHelpers::MethodData<bool() const>(14, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool),
        // Method 'transportIds'
        QtMocHelpers::MethodData<QList<int>() const>(15, 4, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 16),
        // Method 'transportNames'
        QtMocHelpers::MethodData<QStringList() const>(17, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QStringList),
        // Method 'defaultTransportName'
        QtMocHelpers::MethodData<QString() const>(18, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
        // Method 'defaultTransportId'
        QtMocHelpers::MethodData<int() const>(19, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Int),
        // Method 'setDefaultTransport'
        QtMocHelpers::MethodData<void(int)>(20, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Method 'removeTransport'
        QtMocHelpers::MethodData<void(int)>(21, 4, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TransportManager, qt_meta_tag_ZN13MailTransport16TransportManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject MailTransport::TransportManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MailTransport16TransportManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MailTransport16TransportManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13MailTransport16TransportManagerE_t>.metaTypes,
    nullptr
} };

void MailTransport::TransportManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TransportManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->transportsChanged(); break;
        case 1: _t->changesCommitted(); break;
        case 2: _t->passwordsChanged(); break;
        case 3: _t->transportRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->transportRenamed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 5: _t->d->slotTransportsChanged(); break;
        case 6: { bool _r = _t->isEmpty();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { QList<int> _r = _t->transportIds();
            if (_a[0]) *reinterpret_cast<QList<int>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QStringList _r = _t->transportNames();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 9: { QString _r = _t->defaultTransportName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 10: { int _r = _t->defaultTransportId();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->setDefaultTransport((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->removeTransport((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TransportManager::*)()>(_a, &TransportManager::transportsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportManager::*)()>(_a, &TransportManager::changesCommitted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportManager::*)()>(_a, &TransportManager::passwordsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportManager::*)(int , const QString & )>(_a, &TransportManager::transportRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransportManager::*)(int , const QString & , const QString & )>(_a, &TransportManager::transportRenamed, 4))
            return;
    }
}

const QMetaObject *MailTransport::TransportManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MailTransport::TransportManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MailTransport16TransportManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MailTransport::TransportManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void MailTransport::TransportManager::transportsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MailTransport::TransportManager::changesCommitted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MailTransport::TransportManager::passwordsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MailTransport::TransportManager::transportRemoved(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void MailTransport::TransportManager::transportRenamed(int _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
